package com.kk;

import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import java.io.FileOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public class LotteryDrawing {

    public static List<Integer> generateLotteryNumbers(int quantity, int minValue, int maxValue) {
        List<Integer> numbers = new ArrayList<>();
        for (int i = minValue; i <= maxValue; i++) {
            numbers.add(i);
        }

        Collections.shuffle(numbers);
        List<Integer> lotteryNumbers = numbers.subList(0, quantity);
        Collections.sort(lotteryNumbers);

        return lotteryNumbers;
    }

    public static void exportToExcel(List<Integer> lotteryNumbers, String fileName) throws IOException {
        Workbook workbook = new XSSFWorkbook();
        Sheet sheet = workbook.createSheet("Lottery Numbers");

        Row headerRow = sheet.createRow(0);
        headerRow.createCell(0).setCellValue("中奖号码");

        Row dataRow = sheet.createRow(1);
        for (int i = 0; i < lotteryNumbers.size(); i++) {
            dataRow.createCell(i).setCellValue(lotteryNumbers.get(i));
        }

        for (int i = 0; i < lotteryNumbers.size(); i++) {
            sheet.autoSizeColumn(i);
        }

        FileOutputStream fileOut = new FileOutputStream(fileName);
        workbook.write(fileOut);
        fileOut.close();
        workbook.close();
    }

    public static void main(String[] args) throws IOException {
        int lotteryQuantity = 6;
        int lotteryMinValue = 1;
        int lotteryMaxValue = 49;

        System.out.println("欢迎来到彩票抽奖程序！");
        System.out.printf("接下来将从 %d 到 %d 中抽取 %d 个随机数。%n", lotteryMinValue, lotteryMaxValue, lotteryQuantity);

        List<Integer> lotteryNumbers = generateLotteryNumbers(lotteryQuantity, lotteryMinValue, lotteryMaxValue);
        System.out.println("中奖号码为：" + lotteryNumbers);

        String fileName = "lottery_numbers.xlsx";
        exportToExcel(lotteryNumbers, fileName);
        System.out.println("中奖号码已导出到文件：" + fileName);
    }
}
